@@ -1,7 +1,13 @@
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, TypeVar, Union
+
+from pydantic import BaseModel
 
 JSONType = Union[Dict[str, Any], List[Any]]
 
 # This is more correct, but leads to a whole lot of typing bloat wrt. handling iterables.
 # We assume that the API will always return a list or dict.
 # JSONType = Union[None, int, float, str, Dict[str, Any], List[Any]]
+
+T = TypeVar("T", bound=BaseModel)
+ModelOrDict = Union[T, Dict[str, Any]]
+"""A type that can be either a model or a dict."""
